#!/usr/bin/python
# Juju charm hooks for contrail-cfgm

import sys
from charmhelpers.contrib.contrail.common import (
    Role,
)
from charmhelpers.core.hookenv import (
    log as juju_log,
    Hooks, 
    UnregisteredHookError,
)

hooks = Hooks()
role = Role('cfgm',
            also=['collector'],
            reqd={'database': {},
                  'collector': {},
                  'openstack': {'roledef': 'jamming'}, # contrail-openstack
                  },
            knobs={'ext_routers': [],
                   #'router_asn': 64512,
                   'service_token': "'contrail123'"},
            sfabs=['setup_cfgm', 
                   'verify_cfgm', 
                   'prov_external_bgp', 
                   'prov_metadata_services', 
                   'prov_encap_type'],
            adj={'control': {}, 
                 'compute': {}
                 },
            afabs=['fixup_irond_config'],
            jam=True) # compute needs this

@hooks.hook('install')
def install():
    role.install()
#end install

@hooks.hook('start')
def start():
    role.start(clean=True)
#end start

@hooks.hook('cfgm-relation-joined')
def provided_relation_joined():
    role.jamming()
#end provided_relation_joined

# TODO - do this after requirer is jamming
@hooks.hook('cfgm-relation-changed')
def provided_relation_changed():
    role.adjust()
#end provided_relation_changed

# TODO? Get service_token from keystone relation?
@hooks.hook('database-relation-changed', 
            'collector-relation-changed', 
            'openstack-relation-changed')
def required_relation_changed():
    role.start()
    role.adjust()
#end required_relation_changed

#TODO - needed for --collector_ip --redis_ip --zookeeper_ip_list --cfgm_index
#But.... 
#  fixup_restart_haproxy_in_all_cfgm() does 
#    for host_string in env.roledefs['cfgm']: get() and put()
#cfgm-cluster-relation-joined changed departed

def main():
    try:
        hooks.execute(sys.argv)
    except UnregisteredHookError as e:
        juju_log('Unknown hook {} - skipping.'.format(e))
#end main

if __name__ == '__main__':
    main()
