from mock import MagicMock, patch
import contrail_cfgm as hooks
from test_utils import CharmTestCase

TO_PATCH = [
    'juju_log',
]
TO_PATCH_ROLE = [
    'install',
    'start',
    'adjust',
    'jamming',
]

class TestContrailCfgm(CharmTestCase):

    def setUp(self):
        super(TestContrailCfgm, self).setUp(hooks, TO_PATCH)
        super(TestContrailCfgm, self).setUp(hooks.role, TO_PATCH_ROLE)

    def _call_hook(self, hookname):
        hooks.hooks.execute([
            'hooks/{}'.format(hookname)])

    def test_role(self):
        self.assertEqual(hooks.role.role, 'cfgm')
        self.assertEqual(hooks.role.also, ['collector'])
        self.assertEqual(hooks.role.reqd, 
                         {'openstack': {'roledef': 'jamming'}, 
                          'collector': {}, 'database': {}})
        self.assertEqual(hooks.role.knobs, 
                         {'ext_routers': [], 'service_token': "'contrail123'"})
        self.assertEqual(hooks.role.sfabs, 
                         ['setup_cfgm', 
                          'verify_cfgm', 
                          'prov_external_bgp', 
                          'prov_metadata_services', 
                          'prov_encap_type'])
        self.assertEqual(hooks.role.adj, {'compute': {}, 'control': {}})
        self.assertEqual(hooks.role.afabs, ['fixup_irond_config'])
        self.assertTrue(hooks.role.jam)

    def test_install_hook(self):
        self._call_hook('install')
        self.install.assert_called_with()

    def test_start_hook(self):
        self._call_hook('start')
        self.start.assert_called_with(clean=True)

    def test_required_relation_changed(self):
        self._call_hook('openstack-relation-changed')
        self.start.assert_called_with()
        self._call_hook('collector-relation-changed')
        self.start.assert_called_with()
        self._call_hook('database-relation-changed')
        self.start.assert_called_with()
        self.adjust.assert_called_with()

    def test_provided_relation_joined(self):
        self._call_hook('cfgm-relation-joined')
        self.jamming.assert_called_with()

    def test_provided_relation_changed(self):
        self._call_hook('cfgm-relation-changed')
        self.adjust.assert_called_with()
