from mock import MagicMock, patch
import contrail_compute as hooks
from test_utils import CharmTestCase

TO_PATCH = [
    'juju_log',
]
TO_PATCH_ROLE = [
    'install',
    'start',
    'proceed',
    'join',
]

class TestContrailCompute(CharmTestCase):

    def setUp(self):
        super(TestContrailCompute, self).setUp(hooks, TO_PATCH)
        super(TestContrailCompute, self).setUp(hooks.role, TO_PATCH_ROLE)

    def _call_hook(self, hookname):
        hooks.hooks.execute([
            'hooks/{}'.format(hookname)])

    def test_role(self):
        self.assertEqual(hooks.role.role, 'compute')
        self.assertEqual(hooks.role.also, [])
        self.assertEqual(hooks.role.ifabs, ['install_vrouter', 'upgrade_pkgs'])
        self.assertEqual(hooks.role.reqd, 
                         {'cfgm': {'roledef': 'jamming'}, 
                          'control': {}, 'openstack': {}})
        self.assertEqual(hooks.role.knobs, 
                         {'env.interface_rename': False, 
                          'service_token': "'contrail123'"})
        self.assertEqual(hooks.role.sfabs, ['setup_vrouter'])
        self.assertEqual(hooks.role.pfabs, ['verify_compute'])
        self.assertTrue(hooks.role.jam)

    def test_install_hook(self):
        self._call_hook('install')
        self.install.assert_called_with()

    def test_config_changed_hook(self):
        self._call_hook('config-changed')
        self.proceed.assert_called_with()

    def test_start_hook(self):
        self._call_hook('start')
        self.start.assert_called_with(clean=True)

    def test_required_relation_changed(self):
        self._call_hook('cfgm-relation-changed')
        self.start.assert_called_with()
        self._call_hook('control-relation-changed')
        self.start.assert_called_with()
        self._call_hook('openstack-relation-changed')
        self.start.assert_called_with()

    def test_required_relation_joined(self):
        self._call_hook('cfgm-relation-joined')
        self.join.assert_called_with()

