from mock import MagicMock, patch
import contrail_control as hooks
from test_utils import CharmTestCase

TO_PATCH = [
    'juju_log',
]
TO_PATCH_ROLE = [
    'install',
    'start',
    'join',
]

class TestContrailControl(CharmTestCase):

    def setUp(self):
        super(TestContrailControl, self).setUp(hooks, TO_PATCH)
        super(TestContrailControl, self).setUp(hooks.role, TO_PATCH_ROLE)

    def _call_hook(self, hookname):
        hooks.hooks.execute([
            'hooks/{}'.format(hookname)])

    def test_role(self):
        self.assertEqual(hooks.role.role, 'control')
        self.assertEqual(hooks.role.also, [])
        self.assertEqual(hooks.role.ifabs, [])
        self.assertEqual(hooks.role.reqd, {
                'collector': {}, 'cfgm': {'roledef': 'jamming'}})
        self.assertEqual(hooks.role.knobs, {'router_asn': 64512})
        self.assertEqual(hooks.role.sfabs, 
                         ['setup_control', 
                          'verify_control', 
                          'prov_control_bgp'])
        self.assertFalse(hooks.role.jam)

    def test_install_hook(self):
        self._call_hook('install')
        self.install.assert_called_with()

    def test_start_hook(self):
        self._call_hook('start')
        self.start.assert_called_with(clean=True)

    def test_required_relation_changed(self):
        self._call_hook('collector-relation-changed')
        self.start.assert_called_with()
        self._call_hook('cfgm-relation-changed')
        self.start.assert_called_with()

    def test_required_relation_joined(self):
        self._call_hook('cfgm-relation-joined')
        self.join.assert_called_with()
