#!/usr/bin/python
# Juju charm hooks for contrail-database

import sys
import os
from charmhelpers.contrib.contrail.common import (
    Role,
)
from charmhelpers.core.hookenv import (
    charm_dir,
    log as juju_log,
    Hooks, 
    UnregisteredHookError,
)

# Temporary code to disallow multi-node scenario.
# Note: Ultimate goal is to have multi-node be the default.
def multi_node_allowed():
    cluster_hook = charm_dir() + 'hooks/cluster-relation-joined'
    return os.path.exists(cluster_hook)
#end multi_node_allowed

hooks = Hooks()
role = Role('database')

@hooks.hook('install')
def install():
    role.install()
#end install

@hooks.hook('start')
def start():
    if not multi_node_allowed(): #TODO single_node_allowed via config
        role.start(clean=True) #Don't wait for cluster relation()
#end start

def main():
    juju_log('Database cluster support {}'.format(multi_node_allowed()))
    try:
        hooks.execute(sys.argv)
    except UnregisteredHookError as e:
        juju_log('Unknown hook {} - skipping.'.format(e))
#end main

if __name__ == '__main__':
    main()
