from mock import MagicMock, patch
import contrail_openstack as hooks
from test_utils import CharmTestCase

TO_PATCH = [
    'juju_log',
]
TO_PATCH_ROLE = [
    'install',
    'start',
    'jamming',
]

class TestContrailOpenstack(CharmTestCase):

    def setUp(self):
        super(TestContrailOpenstack, self).setUp(hooks, TO_PATCH)
        super(TestContrailOpenstack, self).setUp(hooks.role, TO_PATCH_ROLE)

    def _call_hook(self, hookname):
        hooks.hooks.execute([
            'hooks/{}'.format(hookname)])

    def test_role(self):
        self.assertEqual(hooks.role.role, 'openstack')
        self.assertEqual(hooks.role.also, [])
        self.assertEqual(hooks.role.ifabs, ['install_openstack', 
                                            'upgrade_pkgs', 
                                            'update_keystone_log'])
        self.assertEqual(hooks.role.reqd, {'cfgm': {}})                        
        self.assertEqual(hooks.role.knobs, {'service_token': "'contrail123'"})
        self.assertEqual(hooks.role.sfabs, ['setup_openstack'])
        self.assertTrue(hooks.role.jam)

    def test_install_hook(self):
        self._call_hook('install')
        self.install.assert_called_with()

    def test_start_hook(self):
        self._call_hook('start')
        self.start.assert_called_with(clean=True)

    def test_required_relation_changed(self):
        self._call_hook('cfgm-relation-changed')
        self.start.assert_called_with()

    def test_provided_relation_joined(self):
        self._call_hook('nova-relation-joined')
        self.jamming.assert_called_with()
        self._call_hook('keystone-relation-joined')
        self.jamming.assert_called_with()
        self._call_hook('openstack-relation-joined')
        self.jamming.assert_called_with()
